import 'package:flutter/material.dart';
import 'package:sghi_core/domain_objects/value_objects/enums.dart';
import 'package:sghi_core/shared_themes/spaces.dart';
import 'package:sghi_core/shared_themes/text_themes.dart';
import 'package:sghi_core/ui_components/src/app_strings.dart';
import 'package:sghi_core/ui_components/src/buttons.dart';
import 'package:sghi_core/ui_components/src/profile_avatar.dart';

class SILProfileBanner extends StatelessWidget {
  const SILProfileBanner({
    required this.backgroundImagePath,
    required this.userPhotoPath,
    required this.profileRoute,
    required this.userName,
    required this.primaryPhone,
    required this.gender,
    this.editable = false,
    this.height = 200.00,
  });

  final String backgroundImagePath;
  final bool editable;
  final double height;
  final String primaryPhone;
  final String profileRoute;
  final String userName;
  final String userPhotoPath;
  final String gender;

  @override
  Widget build(BuildContext context) {
    return Container(
      width: double.infinity,
      height: height,
      decoration: BoxDecoration(
        image: DecorationImage(
          fit: BoxFit.cover,
          image: AssetImage(backgroundImagePath),
        ),
        borderRadius: const BorderRadius.only(
          bottomLeft: Radius.circular(6),
          bottomRight: Radius.circular(6),
        ),
      ),
      child: Stack(
        clipBehavior: Clip.none,
        children: <Widget>[
          Container(
            width: double.infinity,
            height: 200,
            decoration: BoxDecoration(
              gradient: LinearGradient(colors: <Color>[
                Theme.of(context).primaryColor.withOpacity(0.8),
                Theme.of(context).primaryColor.withOpacity(0.4),
              ], begin: Alignment.bottomLeft, end: Alignment.topRight),
            ),
            child: editable
                ? Align(
                    alignment: Alignment.bottomCenter,
                    child: Padding(
                      padding: const EdgeInsets.only(bottom: 30),
                      child: Opacity(
                        opacity: 0.75,
                        child: SILSecondaryButton(
                          onPressed: () {
                            Navigator.pushNamed(context, profileRoute);
                          },
                          text: 'Edit Profile Details',
                          borderColor: Colors.white,
                          textColor: Colors.white,
                          addBorder: true,
                        ),
                      ),
                    ),
                  )
                : null,
          ),
          Positioned(
            bottom: -60,
            left: 20,
            child: Container(
              width: 90,
              height: 90,
              decoration: BoxDecoration(
                shape: BoxShape.circle,
                border: Border.all(
                  width: 2,
                  color: Theme.of(context).primaryColor.withOpacity(0.6),
                ),
              ),
              child: SILProfileAvatar(
                  photoPath: gender == Gender.male.toString()
                      ? maleUserIconPath
                      : femaleUserIconPath),
            ),
          ),
          Positioned(
            bottom: -45,
            left: 130,
            child: Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: <Widget>[
                Text(
                  userName,
                  style: TextThemes.heavySize16Text(Colors.black),
                ),
                verySmallVerticalSizedBox,
                Text(
                  primaryPhone,
                  style: TextThemes.normalSize10Text(Colors.grey),
                ),
              ],
            ),
          ),
          Positioned(
            top: 50,
            left: 15,
            child: IconButton(
              icon: const Icon(
                Icons.arrow_back,
                color: Colors.white,
              ),
              onPressed: () {
                Navigator.pop(context);
              },
            ),
          )
        ],
      ),
    );
  }
}
